@@ -18,7 +18,7 @@ Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301 USA
 *-GNU-GPL-END-*/
 
-/* $Id: server.c,v 1.75 2006/06/07 15:27:43 evertonm Exp $ */
+/* $Id: server.c,v 1.76 2006/07/17 13:47:59 evertonm Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -153,6 +153,9 @@ static void *on_tcp_write(oop_source *src, int sd,
     case EPIPE:
       fprintf(stderr, "write: EPIPE on TCP socket %d\n", sd);
       break;
+    default:
+      fprintf(stderr, "write: errno=%d: %s\n",
+	      errno, strerror(errno));
     }
 
     fprintf(stderr, "write: connection lost on TCP socket %d\n", sd);
@@ -249,6 +252,9 @@ static void *on_tcp_rate_write(oop_source *src, int sd,
     case EPIPE:
       fprintf(stderr, "rate_write: EPIPE on TCP socket %d\n", sd);
       break;
+    default:
+      fprintf(stderr, "rate_write: errno=%d: %s\n",
+	      errno, strerror(errno));
     }
 
     fprintf(stderr, "rate_write: connection lost on TCP socket %d\n", sd);
@@ -589,11 +595,14 @@ static void *on_tcp_keepalive_write(oop_source *src, int sd,
     case EPIPE:
       fprintf(stderr, "keepalive write: EPIPE on TCP socket %d\n", sd);
       break;
+    default:
+      fprintf(stderr, "keepalive write: errno=%d: %s\n",
+	      errno, strerror(errno));
     }
     
     fprintf(stderr, 
-	    "keepalive write: connection lost on TCP socket %d: errno=%d: %s\n", 
-	    sd, errno, strerror(errno));
+	    "keepalive write: connection lost on TCP socket %d\n", 
+	    sd);
     
     if (!session->duration_done)
       report_broken_pipe_stat(stdout, pipe);
