@@ -29,16 +29,17 @@ int nepim_socket_block(int sd);
 int nepim_socket_ttl(int sd, int ttl);
 int nepim_socket_mcast_ttl(int sd, int mcast_ttl);
 int nepim_socket_pmtu(int sd, int pmtu_mode);
-int nepim_socket_opt(int sd, int pmtu_mode, int ttl, int tos);
-int nepim_socket_tcp_opt(int family, int sd, int nodelay);
-int nepim_socket_keepalive(int sd, int keepalive);
+int nepim_socket_opt(FILE *err, int sd, int pmtu_mode, int ttl, int tos);
+int nepim_socket_tcp_opt(FILE *err, int family, int sd, int nodelay);
+int nepim_socket_keepalive(FILE *err, int sd, int keepalive);
 
 int nepim_socket_pmtu_get_mode(int sd);
 int nepim_socket_pmtu_get_mtu(int sd);
 int nepim_socket_get_ttl(int sd);
 int nepim_socket_get_tos(int sd);
 
-int nepim_create_socket(const struct sockaddr *addr, int addr_len,
+int nepim_create_socket(FILE *err,
+			const struct sockaddr *addr, int addr_len,
 			int family,
 			int type,
 			int protocol,
@@ -49,7 +50,8 @@ int nepim_create_socket(const struct sockaddr *addr, int addr_len,
 			int win_send,
 			int nodelay,
 			int tos);
-int nepim_create_listener_socket(struct sockaddr *addr,
+int nepim_create_listener_socket(FILE *err,
+				 struct sockaddr *addr,
 				 int addr_len,
 				 int family,
 				 int type,
@@ -61,7 +63,8 @@ int nepim_create_listener_socket(struct sockaddr *addr,
 				 int win_send,
 				 int nodelay,
 				 int tos);
-int nepim_connect_client_socket(const struct sockaddr *bind, int bind_len,
+int nepim_connect_client_socket(FILE *err,
+				const struct sockaddr *bind, int bind_len,
 				struct sockaddr *addr, int addr_len,
 				int family,
 				int type,
@@ -79,7 +82,7 @@ void nepim_sock_dump_addr(char *buf, int buf_size,
 			  const struct sockaddr *addr,
 			  int addr_len);
 int nepim_sock_family(const struct sockaddr *addr);
-void nepim_sock_show_opt(FILE *out, int sd);
+void nepim_sock_show_opt(FILE *err, FILE *out, int sd);
 
 #endif /* NEPIM_SOCK_H */
 
